@@ -9,11 +9,13 @@ import publication
 import typing_extensions
 
 import aws_cdk.aws_apigateway._jsii
+import aws_cdk.aws_certificatemanager._jsii
 import aws_cdk.aws_cloudfront._jsii
 import aws_cdk.aws_cloudfront_origins._jsii
 import aws_cdk.aws_cloudwatch._jsii
 import aws_cdk.aws_cognito._jsii
 import aws_cdk.aws_dynamodb._jsii
+import aws_cdk.aws_ec2._jsii
 import aws_cdk.aws_elasticsearch._jsii
 import aws_cdk.aws_events._jsii
 import aws_cdk.aws_iam._jsii
@@ -25,14 +27,17 @@ import aws_cdk.aws_kms._jsii
 import aws_cdk.aws_lambda._jsii
 import aws_cdk.aws_lambda_event_sources._jsii
 import aws_cdk.aws_logs._jsii
+import aws_cdk.aws_mediastore._jsii
 import aws_cdk.aws_s3._jsii
+import aws_cdk.aws_s3_notifications._jsii
+import aws_cdk.aws_sagemaker._jsii
 import aws_cdk.aws_sns._jsii
 import aws_cdk.aws_sqs._jsii
 import aws_cdk.aws_stepfunctions._jsii
 import aws_cdk.core._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-solutions-constructs/core", "1.67.0", __name__[0:-6], "core@1.67.0.jsii.tgz"
+    "@aws-solutions-constructs/core", "1.80.0", __name__[0:-6], "core@1.80.0.jsii.tgz"
 )
 
 __all__ = [
